@@ -7,11 +7,9 @@
 
 from .sig import SignalCatch
 from .rate import Rate
+from .simple_process import SimpleProcess
 
-try:
-    from importlib.metadata import version # type: ignore
-except ImportError:
-    from importlib_metadata import version # type: ignore
+from importlib.metadata import version # type: ignore
 
 __author__ = 'Kevin Walchko'
 __license__ = 'MIT'
